==> cloud-3.0.0-rc2.tar.gz: cloud/modules/cloud_service_providers/openstack/src/Plugin/QueueWorker/OpenStackUpdateResourcesQueueWorker.php <==
<?php

namespace Drupal\openstack\Plugin\QueueWorker;

use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\openstack\Service\OpenStackServiceFactoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Processes for Openstack Update Resources Queue.
 *
 * @QueueWorker(
 *   id = "openstack_update_resources_queue",
 *   title = @Translation("Openstack Update Resources Queue"),
 * )
 */
class OpenStackUpdateResourcesQueueWorker extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  use StringTranslationTrait;

  /**
   * The OpenStack Service.
   *
   * @var \Drupal\openstack\Service\OpenStackServiceFactoryInterface
   */
  private $openStackServiceFactory;

  /**
   * A logger instance.
   *
   * @var \Psr\Log\LoggerInterface
   */
  protected $logger;

  /**
   * Constructs a new LocaleTranslation object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param array $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\openstack\Service\OpenStackServiceFactoryInterface $openstack_service_factory
   *   Object for interfacing with OpenStack Service.
   * @param \Drupal\Core\Logger\LoggerChannelFactoryInterface $logger_factory
   *   A logger factory instance.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    array $plugin_definition,
    OpenStackServiceFactoryInterface $openstack_service_factory,
    LoggerChannelFactoryInterface $logger_factory
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);

    $this->openStackServiceFactory = $openstack_service_factory;
    $this->logger = $logger_factory->get('openstack');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('openstack.factory'),
      $container->get('logger.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($data): void {
    $cloud_context = $data['cloud_context'];
    $openstack_method_name = $data['openstack_method_name'];
    $openstack_service = $this->openStackServiceFactory->get($cloud_context);

    if (!method_exists($openstack_service, $openstack_method_name)) {
      $this->logger->error($this->t("The method @openstack_method_name doesn't exist in class OpenStackService.", [
        '@openstack_method_name' => $openstack_method_name,
      ]));
      return;
    }

    $openstack_service->$openstack_method_name();
  }

}

==> cloud-4.0.0-rc1.tar.gz: cloud/modules/cloud_service_providers/openstack/src/Plugin/QueueWorker/OpenStackUpdateResourcesQueueWorker.php <==
<?php

namespace Drupal\openstack\Plugin\QueueWorker;

use Drupal\cloud\Traits\CloudContentEntityTrait;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Drupal\openstack\Service\OpenStackServiceFactoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Processes for Openstack Update Resources Queue.
 *
 * @QueueWorker(
 *   id = "openstack_update_resources_queue",
 *   title = @Translation("Openstack Update Resources Queue"),
 * )
 */
class OpenStackUpdateResourcesQueueWorker extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  use CloudContentEntityTrait;

  /**
   * The OpenStack Service.
   *
   * @var \Drupal\openstack\Service\OpenStackServiceFactoryInterface
   */
  private $openStackServiceFactory;

  /**
   * A logger instance.
   *
   * @var \Psr\Log\LoggerInterface
   */
  protected $logger;

  /**
   * Constructs a new LocaleTranslation object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param array $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\openstack\Service\OpenStackServiceFactoryInterface $openstack_service_factory
   *   Object for interfacing with OpenStack Service.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    array $plugin_definition,
    OpenStackServiceFactoryInterface $openstack_service_factory
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);

    $this->openStackServiceFactory = $openstack_service_factory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('openstack.factory'),
      $container->get('logger.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($data): void {
    $cloud_context = $data['cloud_context'];
    $openstack_method_name = $data['openstack_method_name'];
    $openstack_service = $this->openStackServiceFactory->get($cloud_context);

    if (!method_exists($openstack_service, $openstack_method_name)) {
      $this->logger('openstack')->error($this->t('The method @openstack_method_name does not exist in class OpenStackService.', [
        '@openstack_method_name' => $openstack_method_name,
      ]));
      return;
    }

    $openstack_service->$openstack_method_name();
  }

}
